@@ -416,7 +416,8 @@ gifmr <- function(list,
                   rsdcf = 30,
                   inscf = 5,
                   imputation = "i",
-                  name = "test") {
+                  name = "test",
+                  ...) {
         list <- getdoe(list,
                        rsdcf = rsdcf,
                        inscf = inscf,
@@ -437,7 +438,8 @@ gifmr <- function(list,
                 cex = log10(mean + 1) -
                         4,
                 col = grDevices::rgb(0, 0, 1, 0.2),
-                main = "All peaks"
+                main = "All peaks",
+                ...
         )
 
         col <- grDevices::rainbow(dim(data)[2], alpha = 0.318)
@@ -454,7 +456,8 @@ gifmr <- function(list,
                                                     1) - 4,
                                 col = col[i],
                                 ylim = ms,
-                                main = name
+                                main = name,
+                                ...
                         )
                 }
         }, movie.name = filename, ani.width = 800, ani.height = 500)
@@ -760,3 +763,22 @@ plotridges <- function(data, lv, type = "g") {
                                                            bins = 100) + ggplot2::xlim(-0.5, 0.5) + ggplot2::scale_fill_discrete(name = "Group") +
                 ggplot2::labs(x = "Relative Log Abundance", y = "Samples")
 }
+#' plot density weighted intensity for multiple samples
+#' @param list list with data as peaks list, mz, rt and group information
+#' @param n the number of equally spaced points at which the density is to be estimated, default 512
+#' @param ... parameters for `plot` function
+#' @return Density weighted intensity for multiple samples
+#' @examples
+#' data(list)
+#' plotdwtus(list)
+#' @export
+plotdwtus <- function(list,n=512,...){
+        dwtus <- apply(list$data, 2, function(x) getdwtus(x,n = n))
+        if(!is.null(list$order)){
+                graphics::plot(dwtus~as.numeric(list$order), xlab='Run order', ylab = 'DWTUS', col = as.numeric(as.factor(list$group)),...)
+                graphics::legend('topright',legend = unique(list$group),col = unique(as.numeric(as.factor(list$group))),pch = 19,bty = 'n')
+        }else{
+                graphics::plot(dwtus~as.numeric(as.factor(list$group)),xlab='Group', ylab = 'DWTUS',col = as.numeric(as.factor(list$group)),...)
+                graphics::legend('topright',legend = unique(list$group),col = unique(as.numeric(as.factor(list$group))),pch = 19,bty = 'n')
+        }
+}
